unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Controls, Forms,
  ComCtrls, ImgList, StdCtrls, ToolWin, ExtCtrls ;
  
type
  TDemoType =
   (dDemoDBGrid,
    dDemoDS,            
    dDemoSGrid,
    dDemoMultiSheets,
    dDemoMultiDatasets,
    dDemoColors,
    dDemoBorders,
    dDemoRotation,
    dDemoRanges,                        
    dDemoFormulas,
    dDemoFormatStrings,
    dDemoSpeed,
    dDemoRead,
    dAbout
    );

  TfrmMain = class(TForm)
    StatusBar1: TStatusBar;
    ToolBar1: TToolBar;
    TreeView1: TTreeView;
    Splitter1: TSplitter;
    ToolButton1: TToolButton;
    imgMenu: TImageList;
    Panel1: TPanel;
    imgTree: TImageList;
    ToolButton2: TToolButton;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure ToolButton1Click(Sender: TObject);
    procedure Label4Click(Sender: TObject);
    procedure TreeView1Change(Sender: TObject; Node: TTreeNode);
  private
    DemoFrames: array [TDemoType] of TFrame;
    CurrentDemoFrame: TFrame;
    procedure ShowDemo(ADemoType: TDemoType);
  end;

var
  frmMain: TfrmMain;

function GetNextDemoFileName: String;
procedure OpenFile(AFile: string);

implementation
{$R *.dfm}

uses ShellAPI, demodbgrid, demods, demosgrid, democolor, demoborder, demorotation,
  demospeed, demorange, demoformula, demoformat, demomultsheets, demomultds,
  demoread;

var
  FDemoFileNumber: Integer;

procedure OpenFile(AFile: string);
begin
  ShellExecute(0, 'open', PChar(AFile), nil, nil, SW_SHOW);
end;

function GetNextDemoFileName: String;
begin
  result:= 'demo' + IntToStr(FDemoFileNumber) + '.xls';
  Inc(FDemoFileNumber);
end;

procedure TfrmMain.FormCreate(Sender: TObject);
var
  T: TDemoType;
  I: Integer;
begin
  inherited;

  FDemoFileNumber:= 1;

  for T:= Low(TDemoType) to High(TDemoType) do
    DemoFrames[T]:= nil;
  CurrentDemoFrame:= nil;

  for I:= 0 to TreeView1.Items.Count - 1 do
    TreeView1.Items[I].Expand(True);
end;

procedure TfrmMain.FormClose(Sender: TObject; var Action: TCloseAction);
var
  T: TDemoType;
begin
  Action:= caFree;
  for T:= Low(TDemoType) to High(TDemoType) do
    if Assigned(DemoFrames[T]) then
      DemoFrames[T].Destroy;
end;

procedure TfrmMain.ShowDemo(ADemoType: TDemoType);
var
  OldCursor: TCursor;
begin
  if not Assigned(DemoFrames[ADemoType]) then
  begin
    OldCursor:= Screen.Cursor;
    Screen.Cursor:= crHourGlass;
    try
      case ADemoType of
        dDemoDBGrid        : DemoFrames[ADemoType]:= TfraDemoDBGrid.Create(Self);
        dDemoDS            : DemoFrames[ADemoType]:= TfraDemoDS.Create(Self);
        dDemoSGrid         : DemoFrames[ADemoType]:= TfraDemoSGrid.Create(Self);
        dDemoMultiSheets   : DemoFrames[ADemoType]:= TfraDemoMultiSheets.Create(Self);
        dDemoMultiDatasets : DemoFrames[ADemoType]:= TfraDemoMultiDSOneSheet.Create(Self);
        dDemoColors        : DemoFrames[ADemoType]:= TfraDemoColor.Create(Self);
        dDemoBorders       : DemoFrames[ADemoType]:= TfraDemoBorders.Create(Self);
        dDemoRotation      : DemoFrames[ADemoType]:= TfraDemoRotation.Create(Self);
        dDemoRanges        : DemoFrames[ADemoType]:= TfraDemoRanges.Create(Self);
        dDemoFormulas      : DemoFrames[ADemoType]:= TfraDemoFormulas.Create(Self);
        dDemoFormatStrings : DemoFrames[ADemoType]:= TfraDemoFormats.Create(Self);
        dDemoSpeed         : DemoFrames[ADemoType]:= TfraDemoSpeed.Create(Self);
        dDemoRead          : DemoFrames[ADemoType]:= TfraDemoRead.Create(Self);
      end;
    finally
      Screen.Cursor:= OldCursor;
    end;
  end;

  if Assigned(DemoFrames[ADemoType]) and
     (DemoFrames[ADemoType] <> CurrentDemoFrame) then
  begin
    DemoFrames[ADemoType].Parent:= Panel1;
    if Assigned(CurrentDemoFrame) then
      CurrentDemoFrame.Visible:= False;
    DemoFrames[ADemoType].Align:= alClient;
    DemoFrames[ADemoType].Visible:= True;
    CurrentDemoFrame:= DemoFrames[ADemoType];
  end
  else
  if (ADemoType = dAbout) then
  begin
    if Assigned(CurrentDemoFrame) then
      CurrentDemoFrame.Visible:= False;
    CurrentDemoFrame:= nil;
  end;        
end;

procedure TfrmMain.TreeView1Change(Sender: TObject; Node: TTreeNode);
begin
  if Assigned(Node) then
  begin
    if Node.Text = 'TXLSExportDBGrid' then
      ShowDemo(dDemoDBGrid)
    else if Node.Text = 'TXLSExportDataSource' then
      ShowDemo(dDemoDS)
    else if Node.Text = 'TXLSExportStringGrid' then
      ShowDemo(dDemoSGrid)
    else if Node.Text = 'Multiple sheets export' then
      ShowDemo(dDemoMultiSheets)
    else if Node.Text = 'Multiple datasets - one sheet export' then
      ShowDemo(dDemoMultiDatasets)

    else if Node.Text = 'Colored cells' then
      ShowDemo(dDemoColors)
    else if Node.Text = 'Border styles' then
      ShowDemo(dDemoBorders)
    else if Node.Text = 'Text rotation' then
      ShowDemo(dDemoRotation)

    else if Node.Text = 'Ranges, cell merging' then
      ShowDemo(dDemoRanges)
    else if Node.Text = 'Formulas' then
      ShowDemo(dDemoFormulas)
    else if Node.Text = 'Format strings' then
      ShowDemo(dDemoFormatStrings)
    else if Node.Text = 'TXLSFile speed demo' then
      ShowDemo(dDemoSpeed)

    else if Node.Text = 'TXLSFile read demo' then
      ShowDemo(dDemoRead)

    else if Node.Text = 'About this demo' then
      ShowDemo(dAbout)
  end;
end;

procedure TfrmMain.ToolButton1Click(Sender: TObject);
begin
  Close;
end;

procedure TfrmMain.Label4Click(Sender: TObject);
begin
  OpenFile(Label4.Caption);
end;

end.
